
RELEASE_VERSION='0.3.957833289'
BUILD_DATE='Mon Aug  7 08:54:49 UTC 2023'
BUILD_MACHINE_INFO='Linux runner-5w-mmpfk-project-28359933-concurrent-447x4m 5.4.235-144.344.amzn2.x86_64 #1 SMP Sun Mar 12 12:50:22 UTC 2023 x86_64 GNU/Linux'
GITLAB_CI_JOB_ID='4815640913'
GIT_COMMIT_SHA='60a7c69ae6cddef5c37c3066bc61cb4d1954575c'
GIT_BRANCH='main'
